@@ -11,7 +11,7 @@ fn main() {
     App::new()
         .add_plugins(DefaultPlugins)
         .add_plugin(InspectorPlugin::<Data>::new())
-        .add_startup_system(setup.system())
+        .add_startup_system(setup)
         .run();
 }
 
