@@ -112,17 +112,22 @@ where
 {
     let world_ptr = world as *mut _;
 
-    let egui_context = world.get_resource::<EguiContext>().expect("EguiContext");
-    let ctx = {
+    let window_id = {
         let params = world.get_resource::<WorldInspectorParams>().unwrap();
         if !params.enabled {
             return;
         }
-        let ctx = match egui_context.try_ctx_for_window(params.window) {
+        params.window
+    };
+
+    let mut egui_context = world
+        .get_resource_mut::<EguiContext>()
+        .expect("EguiContext");
+    let ctx = {
+        match egui_context.try_ctx_for_window_mut(window_id) {
             Some(ctx) => ctx,
-            None => return,
-        };
-        ctx
+            _ => return,
+        }
     };
     let world: &mut World = unsafe { &mut *world_ptr };
     let mut params = world.get_resource_mut::<WorldInspectorParams>().unwrap();
@@ -134,7 +139,7 @@ where
         .show(ctx, |ui| {
             crate::plugin::default_settings(ui);
             let world: &mut World = unsafe { &mut *world_ptr };
-            let mut ui_context = WorldUIContext::new(world, Some(egui_context.ctx()));
+            let mut ui_context = WorldUIContext::new(world, Some(ctx));
             ui_context.world_ui::<F>(ui, &mut params);
         });
 
